Criar um catálogo AWS EC2

Last published : Nov 03, 2026
Criar catálogos de máquinas descreve os assistentes que criam um catálogo de máquinas. As informações a seguir cobrem detalhes específicos para ambientes de virtualização AWS EC2.
Nota:
Antes de criar um catálogo AWS, você precisa concluir a criação de uma conexão com a AWS. Consulte Conexão com AWS EC2.

Configuração de rede durante a preparação da imagem

Durante a preparação da imagem, uma máquina virtual (VM) de preparação é criada com base na VM original. Esta VM de preparação é desconectada da rede. Para desconectar a rede da VM de preparação, um grupo de segurança de rede é criado para negar todo o tráfego de entrada e saída. Este grupo de segurança de rede persiste e é reutilizado. O nome do grupo de segurança de rede é Citrix.XenDesktop.IsolationGroup-GUID, onde GUID é gerado aleatoriamente.

Tenancy da AWS

A AWS oferece as seguintes opções de tenancy:
  • Tenancy compartilhada (o tipo padrão) e tenancy dedicada. Tenancy compartilhada significa que várias instâncias do Amazon EC2 de diferentes clientes podem residir na mesma peça de hardware físico.
  • Tenancy dedicada significa que suas instâncias EC2 são executadas apenas em hardware com outras instâncias que você implantou. Outros clientes não usam a mesma peça de hardware.

Requisitos para provisionamento em hosts AWS

  • Uma imagem BYOL (traga sua própria licença) importada (AMI). Com hosts dedicados, use e gerencie suas licenças existentes.
  • Uma alocação de hosts dedicados com utilização suficiente para satisfazer as solicitações de provisionamento.
  • Habilitar o auto-placement.

Opções para configurar a tenancy da AWS

  • Usar hardware compartilhado. Esta configuração é adequada para a maioria das implantações. Vários clientes compartilham partes do hardware, embora não interajam entre si. Usar hardware compartilhado é a opção menos dispendiosa para executar suas instâncias do Amazon EC2.
  • Usar host dedicado. Um host dedicado do Amazon EC2 é um servidor físico com capacidade de instância EC2 totalmente dedicada, permitindo que você use licenças de software existentes por soquete ou por VM. Hosts dedicados têm utilização predefinida com base no tipo de instância. Por exemplo, um único host dedicado alocado de tipos de instância C4 Large é limitado a executar 16 instâncias. Consulte o site da AWS para obter mais informações.
    Esta configuração é adequada para implantações com restrições de licenciamento ou requisitos de segurança que exigem o uso de um host dedicado. Com um host dedicado, você possui um host físico inteiro e é cobrado por hora. Possuir esse host permite que você crie quantas instâncias EC2 o host permitir, sem custos adicionais.
  • Usar instância dedicada. Esta configuração é mais adequada para implantações com requisitos específicos de segurança ou conformidade. Com uma instância dedicada, você ainda desfruta dos benefícios de ter um host separado de outros clientes AWS, mas não paga pelo host inteiro. Você não precisa se preocupar com a capacidade do host, mas é cobrado a uma taxa mais alta pelas instâncias.
Nota:
Você pode excluir qualquer disco de identidade de preparação disponível se não houver uma tarefa de criação de catálogo ou atualização de imagem em andamento.
Para configurar a tenancy da AWS usando o Studio, consulte Criar um catálogo usando o Studio e, usando o PowerShell, consulte Configurar a tenancy de host dedicado da AWS usando o PowerShell.

Marcar recursos operacionais da AWS

Uma Amazon Machine Image (AMI) representa um tipo de appliance virtual usado para criar uma máquina virtual dentro do ambiente Amazon Cloud, comumente referido como EC2. Você usa uma AMI para implantar serviços que usam o ambiente EC2. Ao criar um catálogo para provisionar máquinas usando o MCS para AWS, você seleciona a AMI para atuar como a imagem dourada para esse catálogo.
Importante:
A criação de catálogos usando um perfil de máquina e um modelo de inicialização é necessária para usar a marcação de recursos operacionais.
Para criar um catálogo AWS, você deve primeiro criar uma AMI para a instância que deseja que seja a imagem dourada. O MCS lê as tags dessa instância e as incorpora no modelo de inicialização. As tags do modelo de inicialização são então aplicadas a todos os recursos Citrix® criados em seu ambiente AWS, incluindo:
  • Máquinas Virtuais
  • Discos de VM
  • Interfaces de rede de VM
  • Buckets S3
  • Objetos S3
  • Modelos de inicialização
  • AMIs
Você pode marcar recursos operacionais usando o Studio e o PowerShell ao criar um catálogo. Para o Studio, consulte Criar um catálogo usando o Studio (página Imagem). Para o PowerShell, consulte Marcar recursos operacionais usando o PowerShell.
Você pode criar um catálogo usando:

Criar um catálogo usando o Studio

  1. Clique em Catálogos de Máquinas no painel de navegação esquerdo.
  2. Clique em Criar Catálogo de Máquinas. A página Configuração do Catálogo de Máquinas é exibida.
  3. Na página Tipo de Máquina, selecione um tipo de máquina para o catálogo, por exemplo, SO multissessão.
  4. Na página Gerenciamento de Máquinas, selecione as seguintes configurações:
    1. Selecione Máquinas que têm gerenciamento de energia (por exemplo, máquinas virtuais ou PCs blade).
    2. Selecione Tecnologia de provisionamento Citrix. Em seguida, selecione Citrix Machine Creation Services™.
    3. No campo Recursos, selecione os recursos (Zona de Disponibilidade ou Zona Local) que você configurou ao criar a conexão do host e clique em Avançar.
  5. Na página Experiência da área de trabalho, selecione a área de trabalho aleatória ou estática que você deseja que os usuários tenham ao fazer login.
  6. Na página Imagem:
    1. Selecione um modelo de máquina que você deseja usar como imagem mestre para todas as máquinas no catálogo.
    2. Se você quiser que as VMs no catálogo herdem as configurações de um perfil de máquina, selecione um perfil de máquina. Por padrão, a caixa de seleção Usar um perfil de máquina está selecionada. Para alterar a origem do perfil de máquina para outra VM ou versão de modelo de inicialização, clique no botão editar.
    3. Se o modelo de máquina tiver dois volumes, a opção Provisionar um disco de dados será habilitada por padrão. Nesse caso, os perfis de máquina são filtrados apenas com as instâncias ou modelos de inicialização com dois volumes (que especificam as propriedades de hardware, por exemplo, mapeamento de dispositivo de bloco, tipo de volume) para os dois volumes, e modelos de inicialização sem volumes e mapeamentos de dispositivo de bloco definidos.
      Se você desmarcar a caixa de seleção para provisionar um disco de dados, os perfis de máquina serão filtrados apenas com os modelos de inicialização sem volumes e mapeamentos de dispositivo de bloco definidos.
      Para um catálogo MCS baseado em perfil de máquina, você pode usar a mesma VM mestre como origem do disco de dados para o perfil de máquina.
    4. Marque a caixa de seleção Aplicar tags de máquina a recursos operacionais para aplicar tags de máquina a recursos operacionais. Essa opção controla se as tags de máquina devem ser aplicadas a cada item criado em seu ambiente AWS que facilita o provisionamento de máquinas. Os recursos operacionais são criados como subprodutos da criação do catálogo. Eles incluem recursos temporários e persistentes, como instâncias de VM de preparação e AMI.
    Nota:
    A página Segurança aparece somente se você estiver criando um catálogo de máquinas sem atribuir um perfil de máquina.
  7. Na página Máquinas Virtuais:
    1. Insira o número de VMs para o catálogo.
    2. A especificação de máquina padrão é exibida, que é baseada no perfil de máquina. Para alterá-la, selecione o ícone de edição e selecione uma especificação de máquina.
    3. Configure a tenência AWS. Consulte Opções para configurar a tenência AWS.
    4. Você também pode configurar uma VM secundária quando o tamanho da máquina primária atingir a capacidade total. Clique em Tamanho secundário (opcional). Na janela Tamanho da máquina secundária, as VMs listadas têm tipos de VM Spot e Regular. Você pode selecionar até 10 tamanhos de máquina secundária. Depois que as 10 VMs forem selecionadas, as outras VMs listadas serão desabilitadas para seleção futura. Clique em Avançar. No painel Tamanho da máquina secundária, você pode selecionar vários tamanhos de máquina e arrastar e soltar para alterar a ordem de prioridade. Clique em Concluído. Os tamanhos de máquina selecionados aparecem em Tamanho secundário (opcional). Clique no ícone de edição para editar conforme necessário.
  8. A página Segurança aparece somente se você estiver criando um catálogo de máquinas sem atribuir um perfil de máquina. Use a página Segurança para configurar os grupos de segurança para as VMs. Isso também é aplicável ao editar e clonar um catálogo de máquinas existente.
    Se você criar um catálogo de máquinas baseado em perfil de máquina, as configurações do grupo de segurança serão herdadas do perfil de máquina e a página Segurança não aparecerá.
  9. Na página NICs, selecione as NICs (ou ENIs) para as VMs.
  10. Na página Configurações de Disco, escolha se deseja habilitar o cache de write-back.
  11. Na página Identidades da Máquina, configure o Active Directory local ou o Microsoft Entra híbrido para as máquinas no catálogo, selecionando o domínio e criando novas contas AD para as VMs a serem criadas neste catálogo de máquinas. As VMs provisionadas são unidas ao domínio selecionado. Especifique o esquema de nomenclatura de conta para as novas contas AD a serem criadas para as VMs. Clique em Avançar.
  12. Na página Credenciais de domínio, clique em Inserir credenciais para fornecer as credenciais para o domínio selecionado. Insira o nome de usuário e a senha de nível de administrador quando solicitado. Você também pode usar uma conta de serviço se já tiver credenciais de domínio salvas anteriormente, seguindo a documentação do nosso produto.
  13. Avance pelas páginas restantes até a página Resumo. Se você selecionar para provisionar um disco de dados na página Imagens, o valor de Usar disco de dados será definido como true na página Resumo. Insira um nome para o catálogo de máquinas e selecione Concluir para criar o catálogo de máquinas.

Limitações na criação de um catálogo de máquinas em uma zona local da AWS

  • Certas zonas locais suportam apenas certas configurações de hardware (por exemplo, a zona local de Perth não suporta volumes GP3, apenas GP2).
  • Como apenas gp2 é universalmente suportado em todas as zonas locais, e nem todas suportam gp3, a criação de disco de ID padroniza o uso do tipo de volume gp2.
  • Você deve selecionar um perfil de máquina com especificações de hardware que sejam suportadas na zona local desejada.
  • Os snapshots de AMIs de imagem preparada e os snapshots de disco de ID são padronizados para serem colocados na região, em vez da zona local (devido às limitações da AWS em relação à visibilidade do suporte a snapshots EBS em zonas locais).
  • Apenas zonas locais que suportam serviços EC2 e EBS completos são zonas suportadas.

Criar um catálogo usando PowerShell

Configurar a locação de host dedicado AWS usando o PowerShell

Alternativamente, você pode provisionar hosts dedicados AWS através do PowerShell. Use o cmdlet New-ProvScheme com o parâmetro TenancyType definido como Host.

Marcar recursos operacionais usando PowerShell

Para usar o PowerShell para marcar recursos:
  1. Abra uma janela do PowerShell a partir do host DDC.
  2. Execute o comando asnp citrix para carregar módulos PowerShell específicos da Citrix.
Para marcar um recurso para uma VM provisionada, use a propriedade personalizada AwsOperationalResourcesTagging. Exemplo:
New-ProvScheme -ProvisioningSchemeName test
-CustomProperties “AwsOperationalResourcesTagging,true”
-MachineProfile "XDHyp:\HostingUnits\xxxx-ue1a\machineprofiletest (lt-01xxxxx).launchtemplate\lt-01xxxxx (1).launchtemplateversion"
... <Other <standard provscheme parameters>

Catálogo habilitado para MCSIO

A Otimização de Armazenamento MCS (MCSIO) melhora o desempenho da VM armazenando em cache as operações de disco na memória ou em um disco pequeno de alta velocidade. Você pode criar um catálogo não persistente habilitado para MCSIO usando comandos PowerShell. Para criar tal catálogo, você deve instalar o driver MCSIO durante a instalação ou atualização do VDA, durante a preparação da instância AMI. Por padrão, esse driver não é instalado.
Depois que uma AMI MCSIO é preparada (ao instalar o VDA, selecione a opção para incluir o driver MCSIO na instalação), você pode criar um catálogo não persistente habilitado para MCSIO.
Nota:
A opção de configurar o MCSIO apenas com cache de disco (sem cache de memória) usando o Studio foi removida em todos os hipervisores e ambientes de serviço em nuvem.

Criar um catálogo habilitado para MCSIO

Os quatro parâmetros adicionados ao comando PowerShell New-ProvScheme são:
  • UseWriteBackCache: Ativa o cache (cache de write-back) para o esquema de provisionamento fornecido
  • WriteBackCacheDiskSize: Especifica o tamanho em GB do disco temporário usado para cache
  • WriteBackCacheMemorySize: Especifica a quantidade de memória em MB a ser usada para cache. Este é um parâmetro opcional.
Nota:
  • O valor de WriteBackCacheDiskSize deve ser maior que zero porque é necessário pelo menos 1 GB de armazenamento em disco de cache. O tamanho do disco de cache não deve ser maior que o tamanho do disco do SO.
  • O valor de WriteBackCacheMemorySize deve ser diferente de zero e menor que o tamanho da memória do catálogo de máquinas.
As propriedades personalizadas que afetam o MCSIO são:
  • WBCDiskStorageType: Define o tipo de volume, que é usado para o disco temporário no AWS. Este parâmetro aceita um argumento de string no formato volume-type[:iops][:throughput]. Os seguintes são os tipos de volume:
    • gp2: Não use os parâmetros iops e throughput para este tipo de volume
    • gp3: Use os parâmetros iops e throughput para este tipo de volume
    • io1: Use apenas o parâmetro iops para este tipo de volume
    • io2: Use apenas o parâmetro iops para este tipo de volume
    O tipo de volume padrão é gp2.
  • PersistWBC: Controla se o disco de cache deve ser mantido ou descartado sempre que a instância AWS é desligada. Se definido como true, o disco de cache é mantido. Se definido como false (o padrão), o disco de cache é criado e mantido apenas enquanto a instância AMI estiver ligada.
  • PersistOSDisk: Controla se o disco do SO deve ser mantido ou descartado sempre que a instância AWS é desligada. Se definido como true, o disco do SO é mantido. Se definido como false (o padrão), o disco do SO é criado e mantido apenas enquanto a instância AMI estiver ligada.
Execute os seguintes passos na janela do PowerShell para criar um catálogo não persistente com MCSIO habilitado:
  1. Abra a janela do PowerShell.
  2. Execute asnp citrix* para carregar os módulos PowerShell específicos da Citrix.
  3. Crie um catálogo de broker e um pool de identidades.
  4. Crie o esquema de provisionamento. Por exemplo:
    $HostingUnitUid = '0xxxx1d9-bbfc-xxxf-bxxb-exxxxxe008b2'
    $MasterImageVM = 'XDHyp:\HostingUnits\ctx-test\aws-apollo-non-persistent-multi-mcsio-vda-win2022 (ami-0bf1810488acbxxxb).template'
    $NetworkMap = @{ 'NetworkPath' = 'XDHyp:\HostingUnits\ctx-test\us-east-1a.availabilityzone\10.0.128.0`/17 (vpc-0fa6e41d72507fxxx).network' }
    $SecurityGroup = $( 'XDHyp:\HostingUnits\ctx-test\us-east-1a.availabilityzone\private.securitygroup' )
    $ServiceOffering = 'XDHyp:\HostingUnits\ctx-test\T3 Medium Instance.serviceoffering'
    $CustomProperties = 'WBCDiskStorageType,gp3:6000:250;PersistWBC,false'


    $provScheme = New-ProvScheme -ProvisioningSchemeName $CatalogName -HostingUnitUid $HostingUnitUid `
    -IdentityPoolUid $acctPool.IdentityPoolUid -CleanOnBoot `
    - MasterImageVM $MasterImageVM `
    -NetworkMap $NetworkMap `
    -ServiceOffering $ServiceOffering `
    -SecurityGroup $SecurityGroup `
    -CustomProperties $CustomProperties `
    -UseWriteBackCache -WriteBackCacheDiskSize 16 -WriteBackCacheMemorySize 256
  5. Adicione VMs ao catálogo.

Melhore o desempenho de inicialização com MCSIO

Você pode melhorar o desempenho de inicialização das VMs se habilitar o MCSIO e definir as propriedades personalizadas PersistWBC e PersistOSDisk como tru. Com essa configuração, as VMs podem inicializar mais rapidamente porque não precisam inicializar um novo disco de cache ou recriar um disco raiz a partir de seu modelo.

Crie um catálogo de máquinas baseado em perfil de máquina usando PowerShell

Você pode usar um perfil de máquina para capturar as propriedades de hardware de uma instância EC2 (VM) ou versão de modelo de inicialização e aplicá-las às máquinas provisionadas. As propriedades capturadas podem incluir, por exemplo, propriedades de volume EBS, tipo de instância, otimização EBS, opções de CPU, tipo de locação, capacidade de hibernação, grupos de segurança e outras configurações AWS suportadas.
Você pode usar uma instância AWS EC2 (VM) ou uma versão de modelo de inicialização AWS como entrada do perfil da máquina.
Nota:
As propriedades do volume EBS são derivadas apenas de um perfil de máquina.

Considerações importantes

As considerações importantes ao criar um catálogo de máquinas MCS:
  • Se você adicionar parâmetros de propriedade de hardware da máquina nos comandos New-ProvScheme e Set-ProvScheme, os valores fornecidos nos parâmetros sobrescreverão os valores no perfil da máquina.
  • Se você definir AwsCaptureInstanceProperties como true e não definir a propriedade MachineProfile, então apenas as funções e tags do IAM serão capturadas.
  • Você não pode definir AwsCaptureInstanceProperties e MachineProfile ao mesmo tempo.
    Nota:
    O AwsCaptureInstanceProperties está obsoleto.
  • Se um perfil de máquina não for fornecido, você deve fornecer explicitamente os valores das seguintes propriedades:
    • Grupo de Segurança
    • ENI ou Rede Virtual
  • Você pode habilitar AwsOperationalResourcesTagging somente se habilitar AwsCaptureInstanceProperties ou especificar um perfil de máquina.
A consideração importante após criar um catálogo de máquinas MCS é:
  • Você não pode alterar um catálogo de baseado em perfil de máquina para um catálogo não baseado em perfil de máquina.

Configurar grupos de segurança em uma entrada de perfil de máquina

Você pode criar um catálogo de máquinas MCS onde as VMs provisionadas recebem grupos de segurança por ENI (Interface de Rede). Para fazer isso, use uma entrada de perfil de máquina (instância EC2 ou modelo de inicialização) que tenha diferentes grupos de segurança mapeados para ENIs distintas. Por exemplo, se a entrada do perfil da máquina tiver ENI A com SG 1 e ENI B com SG 2, então as VMs provisionadas também devem ter ENI A com SG 1 e ENI B com SG 2.

Recuperar detalhes da interface de rede

Execute os seguintes comandos para obter a lista de registros de dados da interface de rede, incluindo o SubnetId da interface, grupos de segurança atribuídos e redes atribuídas.
(Get-HypInventoryItem -LiteralPath 'XdHyp:\HostingUnits\cvad-test' – ResourceType vm). AdditionalData
Nota:
O MCS atualmente não permite mais de uma rede por interface de rede.

Criar um catálogo de máquinas usando um perfil de máquina

Para criar um catálogo de máquinas usando um perfil de máquina:
  1. Abra uma janela do PowerShell.
  2. Execute asnp citrix* para carregar os módulos PowerShell específicos da Citrix.
  3. Crie um pool de identidades, se ainda não tiver sido criado. Por exemplo,
    New-AcctIdentityPool -IdentityPoolName idPool -NamingScheme ms## -Domain abcdf -NamingSchemeType Numeric
  4. Execute o comando New-ProvScheme. Por exemplo:
    New-ProvScheme -ProvisioningSchemeName demet-test-1
    -HostingUnitUid aa633238-9xxd-4cf6-80e8-232a758a1xx1
    -IdentityPoolUid 34d5b088-e312-416f-907d-16573xxxxxc4
    -CleanOnBoot
    -MasterImageVM 'XDHyp:\HostingUnits\cvad-test-scalestress\citrix-demet-ami.0 (ami-0ca813xxxxxx061ef).template'
    -MachineProfile 'XdHyp:\HostingUnits\cvad-test-scalestress\us-east-1a.availabilityzone\machine-profile-instance i (i-0xxxxxxxx).vm'
  5. Conclua a criação do catálogo.

Atualizar o perfil da máquina

Para atualizar o perfil da máquina em um catálogo que foi inicialmente provisionado com um perfil de máquina, faça o seguinte. Você também pode alterar o tipo de locação e a capacidade de hibernação da origem do perfil da máquina ao editar um catálogo de máquinas MCS.
  1. Execute o comando Set-ProvScheme. Por exemplo,
    Set-ProvScheme `
    -ProvisioningSchemeUid "<ID" `
    -MachineProfile "XDHyp:\HostingUnits\abc\us-east-1a.availabilityzone\citrix-cvad-machineprofile-instance (i-0xxxxxxxx).vm"

Criar um catálogo com a versão do modelo de inicialização usando o PowerShell

Você pode criar um catálogo de máquinas MCS com uma versão de modelo de inicialização como entrada de perfil de máquina. Você também pode atualizar a entrada de um catálogo de perfil de máquina de uma VM para uma versão de modelo de inicialização e de uma versão de modelo de inicialização para uma VM.
No console do AWS EC2, você pode fornecer as informações de configuração da instância de um modelo de inicialização junto com o número da versão. Ao especificar a versão do modelo de inicialização como entrada de perfil de máquina ao criar ou atualizar um catálogo de máquinas, as propriedades dessa versão do modelo de inicialização são copiadas para as VMs VDA provisionadas.
As seguintes propriedades podem ser fornecidas usando a entrada do perfil da máquina ou explicitamente como parâmetros nos comandos New-ProvScheme ou Set-ProvScheme. Se forem fornecidas nos comandos New-ProvScheme ou Set-ProvScheme, elas terão precedência sobre os valores do perfil da máquina dessas propriedades.
  • Oferta de Serviço
  • Redes
  • Tipo de Tenancy
Nota:
Se a oferta de serviço não for fornecida no modelo de inicialização do perfil da máquina ou como um parâmetro no comando New-ProvScheme, você receberá um erro apropriado.
Para criar um catálogo usando a versão do modelo de inicialização como entrada de perfil da máquina:
  1. Abra uma janela do PowerShell.
  2. Execute asnp citrix* para carregar os módulos PowerShell específicos da Citrix.
  3. Obtenha a lista de versões do modelo de inicialização de um modelo de inicialização. Por exemplo:
    XDHyp:\HostingUnits\test\test-mp-sard (lt-01xxxxx).launchtemplate> ls | Select FullPath
  4. Crie um pool de identidades, se ainda não tiver sido criado. Por exemplo:
    New-AcctIdentityPool `
    -IdentityPoolName "abc11" `
    -NamingScheme "abc1-##" `
    -NamingSchemeType Numeric `
    -Domain "citrix-xxxxxx.local" `
    -ZoneUid "xxxxxxxx" `
  5. Crie um esquema de provisionamento com uma versão do modelo de inicialização como entrada de perfil da máquina. Por exemplo:
    New-ProvScheme `
    -ProvisioningSchemeName "MPLT1" `
    -HostingUnitUid "c7f71f6a-3f45-4xxx-xxxx-xxxxxxxxxx" `
    -IdentityPoolUid "bf3a6ba2-1f80-4xxx-xxxx-xxxxxxxxx" `
    -MasterImageVM "XDHyp:\HostingUnits\xxxd-ue1a\apollo-non-persistent-vda-win2022 (ami-0axxxxxxxxxxx).template" `
    -CleanOnBoot `
    -MachineProfile "XDHyp:\HostingUnits\xxxx-ue1a\machineprofiletest (lt-01xxxxx).launchtemplate\lt-01xxxxx (1).launchtemplateversion"
  6. Registre um esquema de provisionamento como um catálogo de broker. Por exemplo:
    New-BrokerCatalog -Name "MPLT1" `
    -AllocationType Random `
    -Description "Machine profile catalog" `
    -ProvisioningSchemeId fe7df345-244e-4xxxx-xxxxxxxxx `
    -ProvisioningType Mcs `
    -SessionSupport MultiSession `
    -PersistUserChanges Discard
  7. Conclua a criação do catálogo.

Atualizar a origem do perfil da máquina

Você também pode atualizar a entrada de um catálogo de perfil de máquina de uma VM para uma versão de modelo de inicialização e de uma versão de modelo de inicialização para uma VM. Por exemplo:
  • Para atualizar a entrada de um catálogo de perfil de máquina de uma VM para uma versão de modelo de inicialização:
    Set-ProvScheme -ProvisioningSchemeName "CloudServiceOfferingTest" `
    -MachineProfile "XDHyp:\HostingUnits\xxxx-ue1a\machineprofiletest (lt-0bxxxxxxxxxxxx).launchtemplate\lt-0bxxxxxxxxxxxx (1).launchtemplateversion"
  • Para atualizar a entrada de um catálogo de perfil de máquina de uma versão de modelo de inicialização para uma VM:
    Set-ProvScheme -ProvisioningSchemeName "CloudServiceOfferingTest" `
    -MachineProfile "XDHyp:\HostingUnits\sard-ue1a\us-east-1a.availabilityzone\apollo-non-persistent-vda-win2022-2 (i-08xxxxxxxxx).vm"

Criptografar discos de SO, ID e WBC

Você pode criar um catálogo persistente e não persistente de VMs com chaves AWS KMS (chave gerenciada pelo cliente e chave gerenciada pela AWS) que podem ser usadas para criptografar disco do SO, disco de identidade (ID) e disco de cache de write-back (WBC).
  • As chaves gerenciadas pela AWS são rotacionadas automaticamente todos os anos.
  • As chaves gerenciadas pelo cliente são opcionais para rotação automática e podem ser gerenciadas manualmente.
Você pode consultar os seguintes documentos da AWS para obter mais informações sobre chaves KMS:
Para criptografia de discos de SO, ID e WBC, configure um dos seguintes:
  • Use uma imagem mestre criptografada (por exemplo, uma AMI criada a partir de uma instância ou snapshot que contém um volume raiz EBS criptografado com chave KMS)
  • Use uma fonte de perfil de máquina (VM ou modelo de inicialização) que contenha um volume raiz EBS criptografado.

Limitações

Considere as seguintes limitações:
  • Atualmente, o MCS suporta apenas um disco na AMI da imagem mestre.
  • Você não pode criptografar diretamente volumes ou snapshots EBS existentes não criptografados, nem modificar a chave KMS de um volume criptografado existente. Para fazer isso, você deve:
    1. Criar um novo snapshot desse volume.
    2. Criar um novo volume a partir desse snapshot
    3. Criptografar o novo volume.
Consulte os seguintes documentos da AWS:

Criar um catálogo com criptografia de disco

Você pode criar um catálogo de máquinas MCS com criptografia de disco usando:
  • Imagem mestre
  • Perfil da máquina
As considerações ao usar a entrada do perfil da máquina são:
  • A chave KMS da entrada do perfil da máquina tem precedência sobre a chave KMS da imagem mestre.
  • Se nenhuma entrada de perfil de máquina for fornecida, a chave KMS da AMI da imagem mestre será usada para criptografar os discos das VMs do catálogo.
  • Se o perfil da máquina tiver Mapeamentos de Dispositivo de Bloco presentes, então os dispositivos de bloco presentes no modelo de imagem mestre (AMI) e no perfil da máquina devem corresponder. Por exemplo, se a AMI tiver um dispositivo definido em /dev/sda1, então o Perfil da Máquina também deve ter um dispositivo definido em /dev/sda1.
  • Se não houver chave na origem do perfil da máquina e a imagem mestre não for criptografada, os discos das VMs do catálogo não serão criptografados.
  • Quando a imagem mestre é criptografada, uma VM de origem de perfil de máquina ou um modelo de inicialização deve ter um volume raiz criptografado para ser considerado uma entrada válida.

Modificar um catálogo existente

Você pode modificar um catálogo existente usando o comando PowerShell Set-ProvScheme para ter:
  • Uma entrada de perfil de máquina com um volume contendo uma nova chave KMS.
  • Um modelo de imagem mestre AMI criptografado com uma nova chave KMS.
Considerações importantes:
  • Os volumes das novas VMs adicionadas ao catálogo são criptografados com a nova chave KMS.
  • Para atualizar as configurações de criptografia quando houver um perfil de máquina existente, execute Set-ProvScheme com um novo perfil de máquina.
  • Você não pode modificar um catálogo existente de volumes criptografados para volumes não criptografados. Você não pode fazer uma atualização de imagem de uma AMI mestre criptografada para uma AMI mestre não criptografada.

Habilitar NitroTPM e inicialização segura UEFI para instâncias de VM

Ao criar um catálogo, agora você pode selecionar uma imagem mestre (AMI) com NitroTPM e/ou inicialização segura UEFI habilitados. Consequentemente, as VMs provisionadas no catálogo também são habilitadas com NitroTPM e/ou inicialização segura UEFI. Essa implementação garante que as VMs sejam seguras e confiáveis. Para obter mais informações sobre NitroTPM e Inicialização Segura UEFI, consulte a documentação da Amazon.

Limitações

  • Você pode usar NitroTPM e Inicialização Segura atualmente em todas as regiões da AWS (incluindo as regiões AWS GovCloud (US)), exceto na China.
  • Você não pode habilitar o NitroTPM e a inicialização segura UEFI em catálogos existentes. Se você deseja um catálogo com NitroTPM e inicialização segura UEFI habilitados, crie um novo catálogo.

Etapas principais

  1. Configure seu ambiente AWS.
  2. Crie uma conexão com a AWS.
  3. Crie um catálogo de máquinas selecionando a imagem mestre com NitroTPM e inicialização segura UEFI habilitados no menu de criação de catálogo do Web Studio ou ao criar um Esquema de Provisionamento usando comandos PowerShell.
As VMs adicionadas ao catálogo criado têm NitoTPM e inicialização segura UEFI habilitados.

Crie uma AMI que suporte NitroTPM e inicialização segura UEFI

  1. Você pode criar uma AMI a partir de uma VM que tenha NitroTPM e/ou inicialização segura UEFI habilitados.
    1. Crie a instância usando as imagens do marketplace da AWS. Exemplo, pesquise por TPM-Windows_Server-2022-English-Full-Base on the aws-marketplace.
    2. Baixe o VDA de sessão única ou múltipla.
    3. Crie uma AMI a partir dessa VM.
  2. Use o comando register-image:
    --boot-mode (string)
    --tpm-support (string)
    Para obter mais informações, consulte register-image.
Consulte os seguintes documentos da AWS:
Você pode abrir uma janela do PowerShell no host do Delivery Controller™ para verificar se um específico:
  • oferta de serviço suporta NitroTPM ou inicialização segura UEFI
    (Get-Item -Path “XDHyp:\HostingUnits\aws\T3 Medium Instance.serviceoffering”).AdditionalData.BootMode
    (Get-Item -Path “XDHyp:\HostingUnits\aws\T3 Medium Instance.serviceoffering”).AdditionalData.NitroTpmSupportVersions
  • modelo suporta NitroTPM ou inicialização segura UEFI
    (Get-HypInventoryItem -LiteralPath “XDHyp:\HostingUnits\aws” -ResourceType “template -Id “ID”).AdditionalData.BootMode

    (Get-HypInventoryItem -LiteralPath “XDHyp:\HostingUnits\aws” -ResourceType “template -Id “ID”).AdditionalData.TpmSupport

Atualizar a oferta de serviço do catálogo existente

Você pode alterar a oferta de serviço de um catálogo existente usando Set-ProvScheme. A alteração se aplica às VMs recém-adicionadas. No entanto, você recebe erros nos seguintes cenários:
Modo de inicialização das AMIs A AMI suporta Nitro TPM? A oferta de serviço suporta NitroTPM e inicialização segura UEFI?
UEFI Não Não
BIOS Legado Sim Não
UEFI Sim Não
UEFI Preferencial Sim Não

Provisionar um disco de dados em uma VM criada pelo MCS

Um disco de dados permite o armazenamento de dados persistentes, como logs de eventos, rastreamentos de segurança e dados de aplicativos.
Você pode criar e atribuir um disco de dados persistente a uma VM persistente ou não persistente criada pelo MCS de um catálogo de máquinas MCS na AWS.
Você pode provisionar discos de dados persistentes com os discos de SO e ID. E a origem do disco de dados deve ser a imagem mestre (volume secundário da AMI).
Você pode criar catálogos MCS baseados em perfil de máquina e não baseados em perfil de máquina. Para catálogos MCS baseados em perfil de máquina, você pode usar a mesma VM de imagem mestre como a origem do disco de dados para o perfil de máquina.

Propriedades do disco de dados

O disco de dados da VM provisionada deriva:
  • Tamanho e nome do dispositivo da AMI
  • Tipo de volume da AMI se o perfil da máquina não for fornecido
Para catálogo baseado em perfil de máquina,
  • Se o disco de dados estiver no modelo de perfil da máquina, a VM provisionada deriva as propriedades do disco de dados, como tag, política de armazenamento e camada de armazenamento, do perfil da máquina.
  • O modelo de perfil da máquina também deve ter um disco de dados no mesmo índice de dispositivo que o disco de dados da AMI
Para catálogo não baseado em perfil de máquina, as informações de hardware são derivadas da AMI da imagem mestre.
O disco de dados também é criptografado com uma chave KMS e herda a chave KMS do disco de dados da AMI ou do perfil da máquina, se a chave KMS for fornecida. No entanto, o KMS do perfil da máquina tem precedência. Não é possível alterar o KMS do disco de dados.

Limitações

As seguintes operações não são atualmente suportadas:
  • Provisionamento de discos de dados não persistentes.
  • Usando um perfil de máquina:
    • sem disco de dados quando a AMI possui um, ou
    • em um índice de disco de dados diferente do da AMI
  • Marcação por disco no momento da criação da instância.
  • Restrições de nome de dispositivo de disco de dados:
    • Para AMIs do Windows, coloque o disco de dados em xvd e não em xvd
    • Para AMIs Linux, coloque o disco de dados em /dev/sd e não em /dev/sd
  • Modificar catálogos e VMs existentes para usar discos de dados.
  • Redefinição do disco de dados.
  • Atualizar uma imagem, de um catálogo existente, que possui um disco de dados com uma imagem que não possui um disco de dados. Somente as novas VMs são atualizadas com o conteúdo da imagem e as propriedades do volume, enquanto as VMs existentes não são atualizadas.
  • Provisionamento de disco WBC com disco de dados.

Criar um catálogo com disco de dados

Você pode criar um catálogo com disco de dados usando o Studio e o PowerShell.
Para o Studio, consulte Criar um catálogo usando o Studio. Além disso, consulte os seguintes pontos importantes:
  • Crie uma imagem mestre (AMI) a partir de uma VM mestre com dois volumes, um do disco do SO (volume raiz) e outro para o disco de dados (volume secundário).
  • Para um catálogo MCS baseado em perfil de máquina, você pode usar a mesma VM mestre como a origem do disco de dados para o perfil de máquina.
  • Durante a criação do catálogo na interface do usuário do Studio, selecione a AMI que você criou com dois volumes como a imagem mestre
  • A opção Provisionar disco de dados está habilitada por padrão.
  • Selecione um perfil de máquina com 2 volumes (instância ou modelo de inicialização) ou 0 volumes (somente modelos de inicialização) que especifique as propriedades de hardware (por exemplo, mapeamento de dispositivo de bloco, tipo de volume) para os dois volumes.
  • Você não pode provisionar um disco de dados quando a imagem mestre (AMI) tem:
    • Um volume: Neste caso, os perfis de máquina são filtrados apenas com as instâncias ou modelos de inicialização com 1 volume, e modelos de inicialização sem volumes e mapeamentos de dispositivo de bloco definidos.
    • Mais de 2 volumes: Neste caso, os perfis de máquina são filtrados com apenas os modelos de inicialização sem volumes e mapeamentos de dispositivos de bloco definidos
  • Conclua a criação do catálogo e o disco de dados será provisionado para as VMs no catálogo

Usar o SDK do PowerShell

  1. Crie uma imagem mestre (AMI) a partir de uma VM mestre com um disco de dados na AWS.
    Para um catálogo MCS baseado em perfil de máquina, você pode usar a mesma VM mestre como a origem do disco de dados para o perfil de máquina.
  2. Crie um catálogo de máquinas MCS com VMs provisionadas com disco de dados usando o comando PowerShell New-ProvScheme com o valor do parâmetro DataDiskPersistence - "Persistent". Por exemplo:
    New-ProvScheme  -CleanOnBoot -HostingUnitName "<HostingUnitName >" -IdentityPoolName "<IdentityPoolName >" -InitialBatchSizeHint 1 -MasterImageVM "<Path to master image item with an additional disk >" -NetworkMapping <NetworkMapping > -ProvisioningSchemeName "<ProvisioningSchemeName >" -DataDisk "" -DataDiskPersistence "Persistent"  -Scope @() -VMCpuCount 4  -VMMemoryMB 6144  -TenancyType Shared  -FunctionalLevel "L7_20"
  3. Adicione VMs ao catálogo usando o comando PowerShell New-ProvVM.

Atualização de imagem com disco de dados

Você pode atualizar a imagem usando Publish-ProvMasterVMImage, no entanto, você não pode atualizar uma imagem de um catálogo existente, contendo um disco de dados com uma imagem que não possui um disco de dados. Depois de atualizar a imagem:
  • Para um catálogo persistente:
    • novas VMs no catálogo têm disco de SO e disco de dados atualizados. As VMs existentes não são atualizadas
  • Para um catálogo não persistente:
    • novas VMs no catálogo têm disco de SO e disco de dados atualizados. O disco de SO das VMs existentes é atualizado na próxima reinicialização, enquanto o disco de dados não é atualizado.

Excluir disco de dados

Se você excluir o catálogo, o disco de dados será excluído, a menos que você use a opção forgetVM ou purgeDBOnly. Se você excluir a VM, o disco de dados será excluído, a menos que você use a opção forgetVM ou purgeDBOnly.
Para catálogos de provisionamento sob demanda, nunca exclua o disco de dados.

Copiar tags em VMs

Você pode copiar tags em NICs e discos (disco de identidade, disco de cache de gravação e disco do SO) que são especificados no perfil da máquina para VMs recém-criadas em um catálogo de máquinas MCS. Você pode especificar essas tags em qualquer uma das fontes de perfil da máquina (instância de VM AWS ou versão de modelo de inicialização AWS). Este recurso é aplicável a catálogos de máquinas e VMs persistentes e não persistentes.
Nota:
  • No console do AWS EC2, você não pode ver os valores de Tag Network Interfaces em Launch Template Version Resource Tags. No entanto, você pode executar o comando PowerShell aws ec2 describe-launch-template-versions --launch-template-id lt-0bb652503d45dcbcd --versions 12 para ver as especificações da tag.
  • Se uma fonte de perfil de máquina (VM ou versão de modelo de inicialização) tiver duas interfaces de rede (eni-1 e eni-2), e eni-1 tiver a tag t1 e eni-2 tiver a tag t2, então a VM receberá as tags de ambas as interfaces de rede.

Filtrar instâncias de VM usando PowerShell

Uma instância de VM AWS que você usa como VM de perfil de máquina deve ser compatível para que o catálogo de máquinas seja criado e funcione corretamente. Para listar as instâncias de VM AWS que podem ser usadas como VMs de entrada de perfil de máquina, você pode usar o comando Get-HypInventoryItem. O comando pode paginar e filtrar o inventário de VMs disponíveis em uma unidade de hospedagem.
Paginação:
Get-HypInventoryItem suporta dois modos de paginação:
  • O modo de paginação usa os parâmetros -MaxRecords e -Skip para retornar conjuntos de itens:
    • -MaxRecords: O padrão é 1. Isso controla quantos itens retornar.
    • -Skip: O padrão é 0. Isso controla quantos itens pular do início absoluto (ou fim absoluto) da lista no hypervisor.
  • O modo de rolagem usa os parâmetros -MaxRecords, -ForwardDirection e -ContinuationToken para permitir a rolagem dos registros:
    • -ForwardDirection: O padrão é True. Isso é usado junto com -MaxRecords para retornar o próximo conjunto de registros correspondentes ou o conjunto anterior de registros correspondentes.
    • -ContinuationToken: Retorna os itens imediatamente depois (ou antes, se ForwardDirection for false), mas não incluindo o item fornecido em ContinuationToken.
Exemplos de paginação:
  • Para retornar um único registro do modelo de máquina com o nome mais baixo. O campo AdditionalData tem o TotalItemsCount e o TotalFilteredItemsCount:
    Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template
  • Para retornar 10 registros do modelo de máquina com o nome mais baixo:
    Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -MaxRecords 10 | select Name
  • Para retornar um array de registros terminando com o nome mais alto:
    Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -ForwardDirection $False -MaxRecords 10 | select Name
  • Para retornar um array de registros começando no modelo de máquina associado ao ContinuationToken fornecido:
    Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -ContinuationToken "ami-07xxxxxxxxxx" -MaxRecords 10
Filtragem:
Os seguintes parâmetros opcionais adicionais são suportados para filtragem. Você pode combinar esses parâmetros com as opções de paginação.
  • -ContainsName "my_name": Se a string fornecida corresponder a parte de um nome de AMI, a AMI será incluída no resultado Get. Por exemplo:
    Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -MaxRecords 100 -ContainName ‘apollo’ | select Name
  • -Tags '{ "Key0": "Value0", "Key1": "Value1", "Key2": "Value2" }': Se uma AMI tiver pelo menos uma dessas tags, ela será incluída no resultado Get. Por exemplo:
    Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -MaxRecords 100 -Tags '{"opex owner": "Not tagged"}' | select Name
    Nota:
    Dois valores de tag são suportados. O valor de tag Não Marcado corresponde a itens que não possuem a tag fornecida em sua lista de tags. O valor de tag Todos os valores corresponde a itens que possuem a tag, independentemente do valor da tag. Caso contrário, a correspondência ocorre somente se o item tiver a tag e o valor for igual ao que é fornecido no filtro.
  • -Id "ami-0a2d913927e0352f3": Se a AMI corresponder ao ID fornecido, ela será incluída no resultado Get. Por exemplo:
    Get-HypInventoryItem -LiteralPath "XDHyp:\HostingUnits\ctx-test" -ResourceType template -Id ami-xxxxxxxxxxxxx
Filtragem no parâmetro AdditionalData:
O parâmetro de filtro AdditionalData lista modelos ou VMs com base em sua capacidade, oferta de serviço ou qualquer propriedade que esteja em AdditionalData. Por exemplo:
(Get-HypInventoryItem -ResourceType "launchtemplateversion" -LiteralPath "XDHyp:\HostingUnits\aws" -MaxRecords 200).AdditionalData
Você também pode adicionar um -Warn parâmetro para indicar as VMs incompatíveis. As VMs são incluídas com um campo AdditionalData chamado Warning. Por exemplo:
(Get-HypInventoryItem -ResourceType "launchtemplateversion" -LiteralPath "XDHyp:\HostingUnits\aws" -MaxRecords 200 -Template "ami-015xxxxxxxxx" -Warn $true).AdditionalData

Lista de SKUs de backup para VMs

As nuvens públicas podem, às vezes, ficar sem capacidade para um tipo específico de instância EC2 (“SKU primário”). Se a configuração da VM primária não estiver disponível, a VM não poderá iniciar, resultando em perda de tempo e interrupção dos negócios. Para resolver esses cenários, forneça uma lista de tipos de instância EC2 de backup (“SKUs de backup”) para os quais o MCS pode recorrer em caso de problemas relacionados à capacidade.
Use uma propriedade personalizada BackupVmConfiguration ao criar ou atualizar um catálogo de máquinas MCS para fornecer uma lista de tipos de instância EC2 de backup (“Lista de SKUs de Backup”).
Se a instância EC2 primária falhar, o MCS tenta recorrer aos tipos de instância EC2 de backup na ordem especificada. Se o MCS não conseguir recorrer a nenhum dos tipos de instância EC2 de backup fornecidos, uma mensagem de erro será exibida. Você pode então tentar ligar a instância EC2 primária novamente. Se isso falhar, o MCS tentará novamente os tipos de instância EC2 de backup.
A lista de SKUs de backup pode ter instâncias sob demanda.
Este recurso é aplicável a catálogos de máquinas MCS persistentes e não persistentes.

Considerações importantes

  • Você pode fornecer vários tipos de instância EC2 de backup na lista de SKUs de backup.
  • A lista de SKUs de backup deve ser única.
  • Uma instância EC2 de backup não pode ser a mesma que a instância EC2 primária.
  • As instâncias EC2 de backup devem ser tipos de instância AWS válidos.
  • Não especifique ofertas de serviço duplicadas. Exemplo: BackupVmConfiguration,t2.small|t3.small|t2.small não é válido.
  • A oferta de serviço especificada na lista deve ser compatível com a configuração do catálogo de máquinas. Por exemplo, se o catálogo usar UEFI e a oferta de serviço especificada na lista de backup não o suportar, a criação ou atualização do catálogo falhará durante o pré-voo.
  • Você pode modificar a lista de SKUs de backup de um catálogo existente usando o comando PowerShell Set-ProvScheme. Você pode modificar VMs existentes usando os comandos PowerShell Set-ProvVM e Set-ProvVMUpdateTimeWindow.

Configurar instâncias EC2 de backup

  1. Abra uma janela do PowerShell.
  2. Execute asnp citrix&ast; para carregar os módulos PowerShell específicos da Citrix.
  3. Crie um catálogo de Broker.
  4. Crie um pool de identidades.
  5. Adicione uma lista de instâncias EC2 de backup usando a propriedade personalizada BackupVmConfiguration e crie um esquema de provisionamento. Por exemplo:
    $serviceOffering = "XDHyp:\HostingUnits\$hostingUnitName\T3 Medium Instance.serviceoffering"
    $customProperties = "AwsCaptureInstanceProperties,false;AwsOperationalResourcesTagging,false;BackupVmConfiguration,t2.small|t2.large|t3.small|t3.large;"
    $createdProvScheme = New-ProvScheme -ProvisioningSchemeName $provisioningSchemeName -HostingUnitName $hostingUnitName -IdentityPoolName $provisioningSchemeName -NetworkMapping $networkMapping -SecurityGroup $securityGroupPath -ServiceOffering $serviceOffering -MasterImageVM $masterImageVm -CustomProperties $customProperties
  6. Atualize o BrokerCatalog com o Id exclusivo do esquema de provisionamento.
  7. Crie e adicione VMs ao catálogo.
Você também pode adicionar instâncias EC2 de backup usando o Studio:
Na página Máquinas Virtuais, clique em Tamanho secundário (opcional). Na janela Tamanho da máquina secundária, as VMs listadas têm tipos de VM Spot e Regular. Você pode selecionar até 10 tamanhos de máquina secundários. Uma vez que as 10 VMs são selecionadas, as outras VMs listadas são desabilitadas para seleção posterior. Clique em Avançar. No painel Tamanho da máquina secundária, você pode selecionar vários tamanhos de máquina e arrastar e soltar para alterar a ordem de prioridade. Clique em Concluído. Os tamanhos de máquina selecionados aparecem em Tamanho secundário (opcional). Clique no ícone de edição para editar conforme necessário. Consulte Criar um catálogo usando o Studio.

Criar um catálogo usando instância Spot do AWS

Em comparação com as instâncias sob demanda, as instâncias Spot oferecem economia de custos de até 90%. As instâncias Spot podem ser interrompidas pelo Amazon EC2 se a capacidade se tornar indisponível, tornando-as adequadas apenas para aplicativos e desktops não críticos.
Para obter informações sobre instâncias Spot, consulte o documento do AWS Spot Instances.
Além disso, você pode usar instâncias Spot como tipo de instância EC2 primária e instância EC2 de backup. Você pode fornecer uma lista de tipos de instância EC2 de backup (“SKUs de Backup” que podem ser instâncias sob demanda e Spot) usando o PowerShell, para os quais o MCS pode recorrer em caso de problemas relacionados à capacidade.

Considerações importantes**

  • Você deve criar um catálogo de instâncias Spot apenas com o fluxo de trabalho de perfil de máquina.
  • Apenas um tipo de solicitação de instância Spot persistente é suportado. Uma solicitação de instância Spot única não é suportada.
  • Apenas os comportamentos de interrupção Parar e Hibernar são suportados.
  • Você pode alterar a configuração de um catálogo existente de instâncias sob demanda para instâncias Spot e vice-versa. No entanto, alterar uma instância EC2 de sob demanda para Spot é complexo. Consulte a documentação da AWS Alternar uma instância EC2 de sob demanda para preço Spot.
  • Ao excluir uma instância Spot provisionada, cancele a solicitação de instância Spot existente. Caso contrário, a AWS criará uma nova instância Spot.

Etapas para criar um catálogo usando instâncias Spot da AWS

  1. Crie uma fonte de perfil de máquina com instância Spot. Para as etapas de criação de uma instância Spot, consulte Criar uma solicitação de instância Spot.
  2. Crie um catálogo de máquinas usando um perfil de máquina com o comando PowerShell New-ProvScheme. Você pode atualizar um catálogo usando o comando Set-ProvScheme.

Usar instâncias Spot como SKU de backup

Você pode usar instâncias Spot como tipo de instância EC2 primária e instância EC2 de backup. Você pode fornecer uma lista de tipos de instância EC2 de backup (“SKUs de Backup” que podem ser instâncias sob demanda e Spot) usando PowerShell para que o MCS possa recorrer em problemas relacionados à capacidade.
Nota:
Você pode especificar instâncias Spot duplicadas na lista de SKUs de backup. Exemplo: BackupVmConfiguration,t2.small:Spot|t2.small|t3.small é válido.

Permissões necessárias

Você precisa das seguintes permissões se usar a instância Spot como uma instância EC2 primária ou de backup:
  • ec2:DescribeSpotInstanceRequests
  • ec2:CancelSpotInstanceRequests

Configurar instâncias Spot de backup

  1. Abra uma janela do PowerShell.
  2. Execute asnp citrix&ast; para carregar os módulos PowerShell específicos do Citrix.
  3. Crie um catálogo do Broker.
  4. Crie um pool de identidades.
  5. Adicione uma lista de instâncias EC2 de backup usando a propriedade personalizada BackupVmConfiguration e crie um esquema de provisionamento. Por exemplo:
    $serviceOffering \= "XDHyp:\\HostingUnits\\$hostingUnitName\\T3 Medium Instance.serviceoffering"  
    $customProperties \= "AwsCaptureInstanceProperties,false;AwsOperationalResourcesTagging,false;BackupVmConfiguration,t2.small|t2.large|t3.small:Spot|t3.large:Spot"  
    $createdProvScheme \= New-ProvScheme \-ProvisioningSchemeName $provisioningSchemeName \-HostingUnitName $hostingUnitName \-IdentityPoolName $provisioningSchemeName \-NetworkMapping $networkMapping \-SecurityGroup $securityGroupPath \-ServiceOffering $serviceOffering \-MasterImageVM $masterImageVm \-CustomProperties $customProperties
  6. Atualize o BrokerCatalog com o ID exclusivo do esquema de provisionamento.
  7. Crie e adicione VMs ao catálogo.

Onde ir a seguir

Mais informações